package com.muyu.common.system.remote.factory;

import com.muyu.common.core.domain.Result;
import com.muyu.common.core.web.page.TableDataInfo;
import com.muyu.common.system.domain.*;
import com.muyu.common.system.remote.RemoteUserService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.cloud.openfeign.FallbackFactory;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Set;

/**
 * 用户服务降级处理
 *
 * @author muyu
 */
@Component
public class RemoteUserFallbackFactory implements FallbackFactory<RemoteUserService> {
    private static final Logger log = LoggerFactory.getLogger(RemoteUserFallbackFactory.class);

    @Override
    public RemoteUserService create (Throwable throwable) {
        log.error("用户服务调用失败:{}", throwable.getMessage());
        return new RemoteUserService() {

            @Override
            public Result<Boolean> registerUserInfo (SysUser sysUser, String source) {
                return Result.error("注册用户失败:" + throwable.getMessage());
            }

            @Override
            public Result<List<SysUser>> companyList() {
                return Result.error("获取企业列表失败:" + throwable.getMessage());
            }

            @Override
            public Result<List<SysEnt>> list(SysEnt sysEnt) {
                return Result.error("获取企业列表失败:" + throwable.getMessage());
            }

            @Override
            public Result<LoginUser> getUserInfo(String firmCode, String userName, String source) {
                return Result.error("获取用户信息失败:" + throwable.getMessage());
            }

            @Override
            public Set<String> getRolePermission(SysUser user) {
                return Set.of();
            }

            @Override
            public Set<String> getMenuPermission(SysUser user) {
                return Set.of();
            }

            @Override
            public Result<SysDept> selectDeptById(Long deptId) {
                return Result.error();
            }

            @Override
            public void insertUserRole(SysUser user) {
                log.warn("新增用户角色失败!");
            }

            @Override
            public void insertUserPost(SysUser user) {
                log.warn("新增用户权限失败!");
            }

            @Override
            public Result addUser(SysUser user) {
                return Result.error(throwable);
            }

        };
    }
}
